@@ -22,6 +22,7 @@ or you can look at the test files in /tests/unit/data/endpoints/valid-rules/
 
 
 import logging
+import os
 import re
 from enum import Enum
 from functools import lru_cache
@@ -29,11 +30,12 @@ from string import Formatter
 from typing import NamedTuple
 
 from botocore import xform_name
-from botocore.compat import quote, urlparse
+from botocore.compat import IPV4_RE, quote, urlparse
 from botocore.exceptions import EndpointResolutionError
 from botocore.utils import (
     ArnParser,
     InvalidArnException,
+    ensure_boolean,
     is_valid_ipv4_endpoint_url,
     is_valid_ipv6_endpoint_url,
     normalize_url_path,
@@ -42,6 +44,18 @@ from botocore.utils import (
 
 logger = logging.getLogger(__name__)
 
+# List of services for which rule-based endpoint resolution is always enabled.
+# This list will change and eventually be removed during minor or patch version
+# changes as part of the rollout of rule-based endpoints resolution.
+ENDPOINT_RESOLUTION_V2_SERVICES = ['s3', 's3control']
+# Feature flag to enable rule-based endpoint resolution for all services.
+# Only for testing use. Rulesets for services may be missing or incomplete
+# until the service is enabled for rule-based endpoint resolution by default.
+# This flag will eventually be removed during a minor or patch version change.
+FORCE_ENDPOINT_RESOLUTION_V2 = ensure_boolean(
+    os.environ.get('BOTO_FORCE_ENDPOINT_RESOLUTION_V2', False)
+)
+
 TEMPLATE_STRING_RE = re.compile(r"\{[a-zA-Z#]+\}")
 GET_ATTR_RE = re.compile(r"(\w+)\[(\d+)\]")
 VALID_HOST_LABEL_RE = re.compile(
@@ -377,6 +391,37 @@ class RuleSetStandardLibary:
         """
         return not value
 
+    def aws_is_virtual_hostable_s3_bucket(self, value, allow_subdomains):
+        """Evaluates whether a value is a valid bucket name for virtual host
+        style bucket URLs. To pass, the value must meet the following criteria:
+        1. is_valid_host_label(value) is True
+        2. length between 3 and 63 characters (inclusive)
+        3. does not contain uppercase characters
+        4. is not formatted as an IP address
+
+        If allow_subdomains is True, split on `.` and validate
+        each component separately.
+
+        :type value: str
+        :type allow_subdomains: bool
+        :rtype: bool
+        """
+        if (
+            value is None
+            or len(value) < 3
+            or value.lower() != value
+            or IPV4_RE.match(value) is not None
+        ):
+            return False
+
+        if allow_subdomains is True:
+            return all(
+                self.aws_is_virtual_hostable_s3_bucket(label, False)
+                for label in value.split(".")
+            )
+
+        return self.is_valid_host_label(value, allow_subdomains=False)
+
 
 class BaseRule:
     """Base interface for individual endpoint rules."""
@@ -574,7 +619,7 @@ class ParameterDefinition:
                 "A parameter must be of type string or boolean."
             )
         self.documentation = documentation
-        self.built_in = builtIn
+        self.builtin = builtIn
         self.default = default
         self.required = required
         self.deprecated = deprecated
@@ -605,9 +650,15 @@ class ParameterDefinition:
 
     def process_input(self, value):
         """Process input against spec, applying default if value is None."""
-        if value is None and self.default is not None:
-            return self.default
-        elif value is not None:
+        if value is None:
+            if self.default is not None:
+                return self.default
+            if self.required:
+                raise EndpointResolutionError(
+                    f"Cannot find value for required parameter {self.name}"
+                )
+            # in all other cases, the parameter will keep the value None
+        else:
             self.validate_input(value)
         return value
 
